@@ -1,14 +1,17 @@
 # -*- coding: utf-8 -*-
 import datetime
+import smart_arg
 
 # Add any Sphinx extension module names here, as strings. They can be extensions
 # coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
     'sphinx.ext.autodoc',
+    'sphinx_autodoc_typehints',
     'sphinx.ext.intersphinx',
     'recommonmark',
 ]
 
+version = release = smart_arg.__version__
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ['_templates']
 
@@ -21,7 +24,7 @@ master_doc = 'index'
 project = u'Smart Argument Suite'
 
 # General information about the project.
-copyright = u'{year}, LinkedIn'.format(year=datetime.datetime.today().year)
+copyright = f'2020-{datetime.datetime.today().year}, LinkedIn'
 
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
