@@ -3,22 +3,19 @@
 This module is an argument serialization and deserialization library that:
 
     - handles two-way conversions: a typed, preferably immutable argument container object
-    (a `NamedTuple` or `dataclass` instance) <==> a command-line argv
+      (a `NamedTuple` or `dataclass` instance) <==> a command-line argv
     - enables IDE type hints and code auto-completion by using `NamedTuple` or `dataclass`
     - promotes type-safety of cli-ready arguments
 
 
 The following is a simple usage example::
 
-    # Define the argument class:
+    # Define the argument container class:
     @arg_suite
     class MyArg(NamedTuple):
         '''MyArg is smart and the docstring goes to description'''
 
         nn: List[int]  # Comments go to ArgumentParser argument help
-        # Each named (without "_" prefix) and fully typed attribute will be turned into an ArgumentParser.add_argument
-        # DISCOURAGED: This only overrides one-way conversion (deserialization of cli) behavior and introduces inconsistencies.
-        _nn = {'choices': (200, 300)}  # (Advanced feature) Optional user supplement/override for `ArgumentParser.add_argument("--nn", **(kwargs|_nn))`
 
         a_tuple: Tuple[str, int]  # Arguments without defaults are treated as "required = True"
         h_param: Dict[str, int]  # Also supports List, Set
@@ -29,10 +26,10 @@ The following is a simple usage example::
         n: Optional[int] = None  # Optional can only default to `None`
 
 
-    # Create the corresponding argument class instance from the command line argument list:
+    # Create the corresponding argument container class instance from the command line argument list:
     # by using
     arg: ArgClass = ArgClass.__from_argv__(sys.argv[1:])  # with factory method, need the manual type hint `:ArgClass` to help IDE
-    # or the monkey-patched constructor of the annotated argument class
+    # or the monkey-patched constructor of the annotated argument container class
     arg = ArgClass(sys.argv[1:])  # with monkey-patched constructor with one positional argument, no manual hint needed
 
     # Create a NamedTuple argument instance and generate its command line counterpart:
@@ -56,18 +53,20 @@ The module contains the following public classes/functions:
 
 All other classes and methods in this module are considered implementation details."""
 
-import pkg_resources
 import logging
 import os
 import sys
-import warnings
 from argparse import Action, ArgumentParser
 from collections import abc
-from types import SimpleNamespace as KwargsType
-from typing import Any, Callable, Dict, Generic, Iterable, List, NamedTuple, Optional, Sequence, Tuple, Type, TypeVar, Union
 from enum import EnumMeta, Enum
+from itertools import chain
+from types import SimpleNamespace
+from typing import Any, Callable, Dict, Generic, Iterable, List, NamedTuple, Optional, Sequence, Tuple, Type, TypeVar, Union
+from warnings import warn
 
-_base_version = '0.4.*'  # star version should be auto-resolved to concrete number when run setup.py
+import pkg_resources
+
+_base_version = '1.1.*'  # star version should be auto-resolved to concrete number when run setup.py
 __version__ = pkg_resources.get_distribution(__name__).version
 __all__ = (
     'arg_suite',
@@ -78,9 +77,11 @@ __all__ = (
     'TypeHandler',
     'PrimitiveHandlerAddon',
 )
-ArgType = TypeVar('ArgType', bound=NamedTuple)  # NamedTuple is not a real class bound, but setting `bound` to NamedTuple makes mypy happier
+
+ArgType = TypeVar('ArgType', bound=NamedTuple)  # NamedTuple is not a real class bound, but this makes mypy happier
 NoneType = None.__class__
 FieldMeta = NamedTuple('FieldMeta', (('comment', str), ('default', Any), ('type', Type), ('optional', bool)))
+KwargsType = SimpleNamespace
 
 logger = logging.getLogger(__name__)
 SMART_ARG_LOG_LEVEL = 'SMART_ARG_LOG_LEVEL'
@@ -88,31 +89,31 @@ if SMART_ARG_LOG_LEVEL in os.environ:
     logger.addHandler(logging.StreamHandler())
     log_level = os.environ[SMART_ARG_LOG_LEVEL].upper()
     logger.setLevel(log_level)
-    logger.info(f"Detected environment var `{SMART_ARG_LOG_LEVEL}, set log level to '{log_level}' and log to stream.")
+    logger.info(f"Detected environment var 'SMART_ARG_LOG_LEVEL', set log level to '{log_level}' and log to stream.")
 
 if sys.version_info >= (3, 8):
     from typing import get_origin, get_args
 elif sys.version_info >= (3, 7):
     # Python == 3.7.x. Defining the back-ported get_origin, get_args
     # 3.7 `List.__origin__ == list`
-    get_origin, get_args = lambda tp: getattr(tp, '__origin__', None), lambda tp: getattr(tp, '__args__', ())
+    get_origin, get_args = lambda tp: getattr(tp, '__origin__', None), lambda tp: getattr(tp, '__args__', [])
 elif sys.version_info >= (3, 6):
     # Python == 3.6.x. Defining the back-ported get_origin, get_args
     # 3.6 `List.__origin__ == List`, `Optional` does not have `__dict__`
     get_origin, get_args = lambda tp: getattr(tp, '__extra__', ()) or getattr(tp, '__origin__', None), lambda tp: getattr(tp, '__args__', ()) or []
 else:
     try:
-        warnings.warn(f"Unsupported and untested python version {sys.version_info} < 3.6. "
-                      f"The package may or may not work properly. "
-                      f"Try 'from typing_inspect import get_origin, get_args' now.")
+        warn(f"Unsupported and untested python version {sys.version_info} < 3.6. "
+             f"The package may or may not work properly. "
+             f"Try 'from typing_inspect import get_origin, get_args' now.")
         from typing_inspect import get_args, get_origin
     except ImportError:
-        warnings.warn(f"`from typing_inspect import get_origin, get_args` failed for "
-                      f"unsupported python version {sys.version_info} < 3.6. It might work with 'pip install typing_inspect'.")
+        warn(f"`from typing_inspect import get_origin, get_args` failed for "
+             f"unsupported python version {sys.version_info} < 3.6. It might work with 'pip install typing_inspect'.")
         raise
 
 frozenlist = tuple  # tuple to simulate an immutable list. [https://www.python.org/dev/peps/pep-0603/#rationale]
-_black_hole = lambda *args, **kwargs: None
+_black_hole = lambda *_, **__: None
 _mro_all = lambda arg_class, get_dict: {k: v for b in (*arg_class.__mro__[-1:0:-1], arg_class) if b.__module__ != 'builtins' for k, v in get_dict(b).items()}
 # note: Fields without type annotation won't be regarded as a property/entry _fields.
 _annotations = lambda arg_class: _mro_all(arg_class, lambda b: getattr(b, '__annotations__', {}))
@@ -138,14 +139,12 @@ def _raise_if(message: str, condition: Any = True):
 
 
 def _first_handles(with_handles, arg_type, default: Optional[bool] = None):
-    for h in with_handles:
-        if h.handles(arg_type):
-            return h
-    return _raise_if(f"{arg_type!r} is not supported.") if default is None else default
+    handle = next(filter(lambda h: h.handles(arg_type), with_handles), default)
+    return handle if handle is not None else _raise_if(f"{arg_type!r} is not supported.")
 
 
 class PrimitiveHandlerAddon:
-    """Primitive handler addon defines some basic operations on primitive types. Only `staticmethod`s are expected.
+    """Primitive handler addon defines some basic operations on primitive types. Only `staticmethod` is expected.
     Users can extend/modify the primitive handling by inheriting this class."""
     @staticmethod
     def build_type(arg_type: Type) -> Union[Type, Callable[[str], Any]]:
@@ -165,15 +164,15 @@ class PrimitiveHandlerAddon:
     @staticmethod
     def build_metavar(arg_type: Type) -> str:
         """Define the hint string in argument help message for `arg_type`."""
-        return '{True, False}' if arg_type == bool else \
-            f"{{{', '.join(str(c) for c in arg_type._member_names_)}}}" if type(arg_type) == EnumMeta else \
+        return '{True, False}' if arg_type is bool else \
+            f"{{{', '.join(map(str, arg_type._member_names_))}}}" if type(arg_type) is EnumMeta else \
             arg_type.__name__
 
     @staticmethod
     def build_choices(arg_type) -> Optional[Iterable[Any]]:
         """Enumerate `arg_type` if possible, or return `None`."""
-        return (True, False) if arg_type == bool else \
-            arg_type if type(arg_type) == EnumMeta else \
+        return (True, False) if arg_type is bool else \
+            arg_type if type(arg_type) is EnumMeta else \
             None
 
     @staticmethod
@@ -222,19 +221,19 @@ class TypeHandler:
         return kwargs
 
     def gen_cli_arg(self, arg: Any) -> Iterable[str]:
-        """Generate command line for argument. This define the serialization process.
+        """Generate command line for argument. This defines the serialization process.
 
         :param arg: value of the argument
         :return: iterable command line str"""
         args = (arg,) if isinstance(arg, str) or not isinstance(arg, Iterable) else arg
-        yield from (_first_handles(self.primitive_addons, type(arg)).build_str(arg) for arg in args)
+        yield from map(lambda a: _first_handles(self.primitive_addons, type(a)).build_str(a), args)
 
     def _type_to_str(self, t: Union[type, Type]) -> str:
         """Convert type to string for ArgumentParser help message
 
         :param t: type of the argument, i.e. float, Dict[str, int], Set[int], List[str] etc.
         :return: string representation of the argument type"""
-        return f'{getattr(t, "_name", "") or t.__name__}[{", ".join(a.__name__ for a in get_args(t))}]'
+        return f'{getattr(t, "_name", "") or t.__name__}[{", ".join(map(lambda a: a.__name__, get_args(t)))}]'
 
     def handles(self, t: Type) -> bool:
         raise NotImplementedError
@@ -271,11 +270,11 @@ class TupleHandler(TypeHandler):
         # get the tuple element types
         types = get_args(arg_type)
         kwargs.nargs = len(types)
-        kwargs.metavar = tuple(_first_handles(self.primitive_addons, t).build_metavar(t) for t in types)
+        kwargs.metavar = tuple(map(lambda t: _first_handles(self.primitive_addons, t).build_metavar(t), types))
         kwargs.type = TupleHandler.__BuildType(types, self.primitive_addons)
 
     def handles(self, t: Type) -> bool:
-        return get_origin(t) == tuple and get_args(t)  # type: ignore
+        return get_origin(t) is tuple and get_args(t)  # type: ignore
 
 
 class CollectionHandler(TypeHandler):
@@ -293,7 +292,7 @@ class CollectionHandler(TypeHandler):
 
 class DictHandler(TypeHandler):
     def _build_other(self, kwargs, arg_type) -> None:
-        addon_method = lambda type, method: getattr(_first_handles(self.primitive_addons, type), method)(type)  # Find the addon for a type and a method
+        addon_method = lambda t, method: getattr(_first_handles(self.primitive_addons, t), method)(t)  # Find the addon for a type and a method
         kv_apply = lambda method, arg_types=get_args(arg_type): (addon_method(arg_types[0], method), addon_method(arg_types[1], method))  # Apply on k/v pair
         k_type, v_type = kv_apply('build_type')
         kwargs.nargs = '*'
@@ -307,11 +306,11 @@ class DictHandler(TypeHandler):
 
     def gen_cli_arg(self, arg):
         arg_to_str = lambda arg_v: _first_handles(self.primitive_addons, type(arg_v)).build_str(arg_v)
-        yield from (f'{arg_to_str(k)}:{arg_to_str(v)}' for k, v in arg.items())
+        yield from map(lambda kv: f'{arg_to_str(kv[0])}:{arg_to_str(kv[1])}', arg.items())
 
     def handles(self, t: Type) -> bool:
         args, addons = get_args(t), self.primitive_addons
-        return len(args) == 2 and get_origin(t) == dict and _first_handles(addons, args[0], False) and _first_handles(addons, args[1], False)
+        return len(args) == 2 and get_origin(t) is dict and _first_handles(addons, args[0], False) and _first_handles(addons, args[1], False)
 
 
 class _namedtuple:  # TODO expand lambdas to static methods or use a better holder representation
@@ -322,7 +321,7 @@ class _namedtuple:  # TODO expand lambdas to static methods or use a better hold
         new_instance = arg_class.__original_new__(arg_class, **kwargs)
         post_init = getattr(arg_class, '__post_init__', None)
         if post_init:
-            fake_namedtuple = KwargsType(**new_instance._asdict())
+            fake_namedtuple = SimpleNamespace(**new_instance._asdict())
             post_init(fake_namedtuple)  # make the faked NamedTuple mutable in post_init only while initialization
             new_instance = arg_class.__original_new__(arg_class, **vars(fake_namedtuple))
         arg_class.__arg_suite__.post_validation(new_instance)
@@ -332,25 +331,25 @@ class _namedtuple:  # TODO expand lambdas to static methods or use a better hold
     def proxy(t: Type):
         """:return This proxy class if `t` is a `NamedTuple` or `None`"""
         b, f, f_t = getattr(t, '__bases__', []), getattr(t, '_fields', []), getattr(t, '__annotations__', {})
-        return _namedtuple if (len(b) == 1 and b[0] == tuple and isinstance(f, tuple) and isinstance(f_t, dict)
-                               and all(type(n) == str for n in f) and all(type(n) == str for n, _ in f_t.items())) else None
+        return _namedtuple if (len(b) == 1 and b[0] is tuple and isinstance(f, tuple) and isinstance(f_t, dict)
+                               and all(map(lambda n: type(n) is str, chain(f, f_t.keys())))) else None
     asdict = lambda args: args._asdict()
     field_default = lambda arg_class, raw_arg_name: arg_class._field_defaults.get(raw_arg_name, MISSING)
-    patch = _black_hole
+    patch = _black_hole  # No need to patch
 
 
 class _dataclasses:
     """dataclass proxy"""
     @staticmethod
     def patch(cls):
-        """Patch the argument dataclass so that `post_validation` is called and it's immutable if not `frozen` after initialization"""
+        """Patch the argument dataclass so that `post_validation` is called, and it's immutable if not `frozen` after initialization"""
         def raise_if_frozen(self, fun, name, *args, **kwargs):
             _raise_if(f"cannot assign to/delete field {name!r}", getattr(self, '__frozen__', False))
             getattr(object, fun)(self, name, *args, **kwargs)
 
         def init(self, *args, **kwargs):
             if args and hasattr(self, '__frozen__'):
-                logger.debug(f"Assuming {self} is from patch new with __from_argv__, already initialized, skipping init.")
+                logger.debug(f"Assuming {self} is from the patched __new__ with __from_argv__, already initialized, skipping init.")
                 return
             self.__original_init__(*args, **kwargs)
             object.__setattr__(self, '__frozen__', True)
@@ -368,13 +367,16 @@ class _dataclasses:
     new_instance = lambda arg_class, _: arg_class.__original_new__(arg_class)
 
 
+_type_proxies = [_namedtuple, _dataclasses]  # Supported container types. Users can extend it if they know what they are doing. Not officially supported yet.
+
+
 def _get_type_proxy(arg_class):
-    return _namedtuple.proxy(arg_class) or _dataclasses.proxy(arg_class)
+    return next(filter(lambda p: p.proxy(arg_class), _type_proxies), False)
 
 
 def _unwrap_optional(arg_type):
     type_origin, type_args, optional = get_origin(arg_type), get_args(arg_type), False
-    if type_origin == Union and len(type_args) == 2 and type_args[1] == NoneType:  # `Optional` support
+    if type_origin is Union and len(type_args) == 2 and type_args[1] is NoneType:  # `Optional` support
         arg_type, optional = type_args[0], True  # Unwrap `Optional` and validate
     return arg_type, optional
 
@@ -383,27 +385,26 @@ class ArgSuite(Generic[ArgType]):
     """Generates the corresponding `ArgumentParser` and handles the two-way conversions."""
     @staticmethod
     def new_arg(arg_class, *args, **kwargs):
-        """Monkey-Patched argument class __new__.
+        """Monkey-Patched argument container class __new__.
         If any positional arguments exist, it would assume that the user is trying to parse a sequence of strings.
         It would also assume there is only one positional argument, and raise an `SmartArgError` otherwise.
-        If no positional arguments exist, it would call the argument class instance creator with all keyword arguments.
+        If no positional arguments exist, it would call the argument container class instance creator with all keyword arguments.
 
         :param arg_class: Decorated class
         :param args: Optional positional argument, to be parsed to the arg_class type.
-               `args[0]`: a optional marker to mark the sub-sequence of `argv` to be parsed by the parser. ``None`` will
+               `args[0]`: an optional marker to mark the sub-sequence of `argv` to be parsed by the parser. ``None`` will
                 be interpreted as ``sys.argv[1:]``
-               `args[1]`: default to `None`, indicating using the default separator for the argument class
+               `args[1]`: default to `None`, indicating using the default separator for the argument container class
 
         :type `(Optional[Sequence[str]], Optional[str])`
-        :param kwargs: Optional keyword arguments, to be passed to the argument class specific instance creator."""
-        logger.info(f"Patched new for {arg_class} is called with {args} and {kwargs}.")
+        :param kwargs: Optional keyword arguments, to be passed to the argument container class specific instance creator."""
+        logger.info(f"Patched __new__ for {arg_class} is called with {args} and {kwargs}.")
         if args:
-            warnings.warn(f"Calling the patched constructor of {arg_class} with argv is deprecated, please use {arg_class}.__from_argv__ instead.")
-            # TODO Exception handling with helpful error message
+            warn(f"Calling the patched constructor of {arg_class} with argv is deprecated, please use {arg_class}.__from_argv__ instead.")
             _raise_if(f"Calling '{arg_class}(positional {args}, keyword {kwargs})' is not allowed:\n"
                       f"Only accept positional arguments to parse to the '{arg_class}'\nkeyword arguments can only be used to create an instance directly.",
                       kwargs or len(args) > 2 or len(args) == 2 and args[1].__class__ not in (NoneType, str)
-                      or not (args[0] is None or isinstance(args[0], Sequence) and all(a.__class__ is str for a in args[0])))
+                      or not (args[0] is None or isinstance(args[0], Sequence) and all(map(lambda a: a.__class__ is str, args[0]))))
 
             return arg_class.__from_argv__(args[0])
         else:
@@ -411,11 +412,11 @@ class ArgSuite(Generic[ArgType]):
 
     def __init__(self, type_handlers: Sequence[TypeHandler], arg_class):
         type_proxy = _get_type_proxy(arg_class)
-        _raise_if(f"Unsupported argument class {arg_class}.", not type_proxy)
+        _raise_if(f"Unsupported argument container class {arg_class}.", not type_proxy)
         self.handlers = type_handlers
         self.handler_actions: Dict[str, Tuple[Union[TypeHandler, Type], Action]] = {}
         type_proxy.patch(arg_class)
-        #  A big assumption here is that the argument classes never override __new__
+        #  A big assumption here is that the argument container classes never override __new__
         if not hasattr(arg_class, '__original_new__'):
             arg_class.__original_new__ = arg_class.__new__
         arg_class.__new__ = ArgSuite.new_arg
@@ -432,7 +433,7 @@ class ArgSuite(Generic[ArgType]):
     def _validate_fields(arg_class: Type) -> None:
         """Validate fields in `arg_class`.
 
-        :raise: SmartArgError if the decorated argument class has non-typed field with defaults and such field
+        :raise: SmartArgError if the decorated argument container class has non-typed field with defaults and such field
                 does not startswith "_" to overwrite the existing argument field property."""
         arg_fields = _annotations(arg_class).keys()
         invalid_fields = tuple(filter(lambda s: s.endswith('_'), arg_fields))
@@ -440,17 +441,17 @@ class ArgSuite(Generic[ArgType]):
         private_prefix = f'_{arg_class.__name__}__'
         l_prefix = len(private_prefix)
         # skip callable methods and typed fields
-        for f in [f for f in (vars(arg_class).keys()) if not callable(getattr(arg_class, f)) and f not in arg_fields]:
+        for f in filter(lambda f: not callable(getattr(arg_class, f)) and f not in arg_fields, vars(arg_class).keys()):
             is_private = f.startswith(private_prefix)
             _raise_if(f"'{arg_class}': there is no field '{f[l_prefix:]}' for '{f}' to override.", is_private and f[l_prefix:] not in arg_fields)
             _raise_if(f"'{arg_class}': found invalid (untyped) field '{f}'.", not (is_private or f.startswith('_')))
 
     def _gen_arguments_from_class(self, arg_class, prefix: str, parent_required, arg_classes: List, type_proxy) -> None:
         """Add argument to the self._parser for each field in the self._arg_class
-        :raise: SmartArgError if cannot find corresponding handler for the argument type"""
-        suite: ArgSuite = getattr(arg_class, '__arg_suite__', None)
-        _raise_if(f"Recursively nested argument class '{arg_class}' is not supported.", arg_class in arg_classes)
-        _raise_if(f"Nested argument class '{arg_class}' with '__post_init__' expected to be decorated.",
+        :raise: SmartArgError if a corresponding handler for the argument type is not found."""
+        _raise_if(f"Recursively nested argument container class '{arg_class}' is not supported.", arg_class in arg_classes)
+        suite = getattr(arg_class, '__arg_suite__', None)
+        _raise_if(f"Nested argument container class '{arg_class}' with '__post_init__' expected to be decorated.",
                   not (suite and suite._arg_class is arg_class) and hasattr(arg_class, '__post_init__'))
         self._validate_fields(arg_class)
         comments = _mro_all(arg_class, self.get_comments_from_source)
@@ -474,9 +475,10 @@ class ArgSuite(Generic[ArgType]):
                                         help=f"nested argument container marker{'' if default in (LateInit, MISSING) else f'; default: {default}'}")
                 else:
                     handler = _first_handles(self.handlers, arg_type)
-                    field_meta = FieldMeta(comment=comments.get(raw_arg_name, ''), default=default, type=arg_type, optional=optional)
-                    kwargs = handler.gen_kwargs(field_meta, parent_required)
                     user_override: dict = getattr(arg_class, f'_{arg_class.__name__}__{raw_arg_name}', {})
+                    comment = user_override.pop('_comment_to_help', comments.get(raw_arg_name, ''))
+                    field_meta = FieldMeta(comment=comment, default=default, type=arg_type, optional=optional)
+                    kwargs = handler.gen_kwargs(field_meta, parent_required)
                     if user_override.get('choices', None):
                         logger.info(f"Instead of defining `choices`, please consider using Enum for {arg_name}")
                     kwargs.__dict__.update(user_override)  # apply user override to the keyword argument object
@@ -489,7 +491,8 @@ class ArgSuite(Generic[ArgType]):
 
     @staticmethod
     def strip_argv(separator: str, argv: Optional[Sequence[str]]) -> Sequence[str]:
-        """Strip any elements outside of `{separator}+` and `{separator}-` of `argv`.
+        """Strip any elements outside `{separator}+` and `{separator}-` of `argv`.
+        :param separator: A string marker prefix to mark the boundaries of the belonging arguments in argv
         :param argv: Input argument list, treated as `sys.argv[1:]` if `None`
         :return: Stripped `argv`"""
         if argv is None:
@@ -503,7 +506,7 @@ class ArgSuite(Generic[ArgType]):
                 b, e = argv.index(l_s), argv.index(r_s)
                 if e > b:
                     return argv[b + 1: e]
-        raise SmartArgError(f"Expecting up to 1 pair of separator '{l_s}' and '{r_s}' in {argv}")
+        raise SmartArgError(f"Expecting up to 1 pair of separator markers'{l_s}' and '{r_s}' in {argv}")
 
     def parse_to_arg(self, argv: Optional[Sequence[str]] = None, separator: Optional[str] = '', *, error_on_unknown: bool = True) -> ArgType:
         """Parse the command line to decorated ArgType
@@ -521,11 +524,11 @@ class ArgSuite(Generic[ArgType]):
                     value = arg_dict.get(arg_name, MISSING)
                     type_origin = get_origin(arg_type)
                     type_args = get_args(arg_type)
-                    type_to_new = get_origin(type_args[0]) if type_origin == Union and len(type_args) == 2 and type_args[1] == NoneType else type_origin
+                    type_to_new = get_origin(type_args[0]) if type_origin is Union and len(type_args) == 2 and type_args[1] is NoneType else type_origin
                     # argparse reading variable length arguments are all lists, need to apply the origin type for the conversion to correct type.
                     value = type_to_new(value) if value is not None and isinstance(value, List) else value  # type: ignore
-                else:  # deal with nested container
-                    is_nested_items_defined = any((name for name in arg_dict.keys() if name.startswith(arg_name)))  # consider defined only if there's subfield
+                else:  # deal with nested container, consider defined only if there's subfield
+                    is_nested_items_defined = any(filter(lambda name: name.startswith(arg_name), arg_dict.keys()))  # type: ignore
                     value = to_arg(_unwrap_optional(arg_type)[0], f'{arg_name}.') if is_nested_items_defined else MISSING
                 if value is not MISSING:
                     nest_arg[raw_arg_name] = value
@@ -534,7 +537,7 @@ class ArgSuite(Generic[ArgType]):
         ns, unknown = self._parser.parse_known_args(argv)
         error_on_unknown and unknown and self._parser.error(f"unrecognized arguments: {' '.join(unknown)}")
         logger.info(f"{argv} is parsed to {ns}")
-        arg_dict = {name: value for name, value in vars(ns).items() if value is not MISSING}  # Filter out defaults added by the parser.
+        arg_dict: Dict[str, Any] = {name: value for name, value in vars(ns).items() if value is not MISSING}  # Filter out defaults added by the parser.
         return to_arg(self._arg_class, '')
 
     def post_validation(self, arg: ArgType, prefix: str = '') -> None:
@@ -545,19 +548,19 @@ class ArgSuite(Generic[ArgType]):
             _raise_if(f"Field '{name}' is still not initialized after post processing for {arg_class}", attr is LateInit)
             attr_class = attr.__class__
             type_origin, type_args = get_origin(t), get_args(t)
-            if _get_type_proxy(t) or type_origin == Union and len(type_args) == 2 and type_args[1] == NoneType and _get_type_proxy(type_args[0]):
+            if _get_type_proxy(t) or type_origin is Union and len(type_args) == 2 and type_args[1] is NoneType and _get_type_proxy(type_args[0]):
                 _raise_if(f"Field {name}' value of {attr}:{attr_class} is not of the expected type '{t}' for {arg_class}", attr_class not in (t, *type_args))
                 self.post_validation(attr, f'{prefix}{name}.')
             else:
                 arg_type = get_origin(t) or t
-                if arg_type == get_origin(Optional[Any]):
+                if arg_type is get_origin(Optional[Any]):
                     arg_type = get_args(t)
                 if arg_type is list and isinstance(attr, tuple) or arg_type is set and isinstance(attr, frozenset):  # allow for immutable replacements
                     continue
                 try:
                     conforming = isinstance(attr, arg_type)  # e.g. list and List
                 except TypeError:  # best effort to check the instance type
-                    logger.warning(f"Unable to check if {attr!r} is of type {t} for field {name!r} of argument class {arg_class}")
+                    logger.warning(f"Unable to check if {attr!r} is of type {t} for field {name!r} of argument container class {arg_class}")
                     conforming = True
                 _raise_if(f"Field {name!r} has value of {attr!r} of type {attr_class} which is not of the expected type '{t}' for {arg_class}", not conforming)
 
@@ -568,9 +571,9 @@ class ArgSuite(Generic[ArgType]):
             default = proxy.field_default(arg_class, name)
             if arg != default:
                 handler_or_proxy, action = self.handler_actions[f'{prefix}{name}']
-                user_override = getattr(arg_class, f'_{arg_class.__name__}__{name}', {}).get('_serialization', None)
+                serialization_user_override = getattr(arg_class, f'_{arg_class.__name__}__{name}', {}).get('_serialization', None)
                 yield action.option_strings[0]
-                yield from user_override(arg) if user_override else \
+                yield from serialization_user_override(arg) if serialization_user_override else \
                     handler_or_proxy.gen_cli_arg(arg) if isinstance(handler_or_proxy, TypeHandler) else \
                     self._gen_cmd_argv(arg, f'{prefix}{name}.')
 
@@ -605,7 +608,7 @@ class ArgSuite(Generic[ArgType]):
         """Generate the command line arguments
 
         :param separator: separator marker, empty str to disable, None to default to class name
-        :param arg: the annotated argument class object
+        :param arg: the annotated argument container class object
         :return: command line sequence"""
         argv = self._gen_cmd_argv(arg, '')
         if separator is None:
@@ -617,7 +620,7 @@ class ArgSuiteDecorator:
     """Generate a decorator to easily convert back and forth from command-line to `NamedTuple` or `dataclass`.
 
     The decorator monkey patches the constructor, so that the IDE would infer the type of
-    the deserialized `arg` for code auto completion and type check::
+    the deserialized `arg` for code auto-completion and type check::
 
         arg: ArgClass = ArgClass.__from_argv__(my_argv)  # Factory method, need the manual type hint `:ArgClass`
         arg = ArgClass(my_argv)  # with monkey-patched constructor, no manual hint needed
@@ -638,10 +641,10 @@ class ArgSuiteDecorator:
 
     :param primitive_handler_addons: the primitive types handling in addition to the provided primitive type basic operations
     :param type_handlers: the types handling in addition to the provided types handling.
-    :return: the argument class decorator"""
+    :return: the argument container class decorator"""
     def __init__(self, type_handlers: Sequence[Type[TypeHandler]] = (), primitive_handler_addons: Sequence[Type[PrimitiveHandlerAddon]] = ()) -> None:
         addons = (*primitive_handler_addons, PrimitiveHandlerAddon)
-        self.handlers = tuple(handler(addons) for handler in (*type_handlers, PrimitiveHandler, CollectionHandler, DictHandler, TupleHandler))
+        self.handlers = tuple(map(lambda handler: handler(addons), chain(type_handlers, (PrimitiveHandler, CollectionHandler, DictHandler, TupleHandler))))
 
     def __call__(self, cls):
         ArgSuite(self.handlers, cls)
@@ -649,4 +652,4 @@ class ArgSuiteDecorator:
 
 
 custom_arg_suite = ArgSuiteDecorator  # Snake case decorator alias for the class name in camel case
-arg_suite = custom_arg_suite()  # Default argument class decorator to expose smart arg functionalities.
+arg_suite = custom_arg_suite()  # Default argument container class decorator to expose smart arg functionalities.
